/**
 * @fileOverview Sample for sending a ControlDoorEx command
 * @name index.js
 * @author Cor Kalis <c.kalis@intoaccess.com>
 * @license UNLICENSED
 */
"use strict";

const async = require('async');
const http = require('http');

const PROTO = 'http:';
const PORT = 8088;
const PATH = '/ControlDoorEx';
const HOST = '192.168.1.52';
const USER = 'RestUser';
const PWD = 'RestPassword';


/**
 * Send a ControlDoorEx command
 * @param {object} obj ControlDoorEx command data object
 * @param {function} callback Called when done
 */
function controlDoorEx(obj, callback) {

  const strObj = JSON.stringify(obj);
  const bufObj = Buffer.from(strObj, 'utf-8');

  const req = http.request(
    {
      protocol: PROTO,
      hostname: HOST,
      port: PORT,
      path: PATH,
      method: 'POST',
      headers: {
        'Content-Type': 'application/json charset=utf-8',
        'Content-Length': Buffer.byteLength(bufObj)
      },
      auth: USER + ":" + PWD
    },
    (res) => {
      let reply = '';

      res.on('data', (chunk) => {
        reply += chunk;
      });

      res.on('end', () => {
        callback(null, reply);
      });
    }
  );

  req.on('error', (err) => {
    callback(err);
  });

  // Write data to request body
  req.write(bufObj);
  req.end();
}

// ======  Main ======

// Doors to control
const DOORS = [6364416, 6377218, 1484506, 2166606];
// Possible functions
const FUNC_CLOSE = 0;
const FUNC_TIMED = 1;
const FUNC_HOLD = 2;

const obj = {
  address: 12345678,
  relais: 0,
  function: FUNC_CLOSE,
  doorOpenTime: 1000,
  ledFlash: 0
};

// Send a command to each door
async.eachSeries(
  DOORS,
  (val, cb) => {
    obj.address = val;
    controlDoorEx(obj, (err, reply) => {
      if (err) {
        cb(err);
      } else if (!reply) {
        cb(new Error('False reply'));
      } else {
        console.log('OK');
        cb();
      }
    });
  },
  (err) => {
    if (err) {
      console.log('Oops:', err);
    }
  }
);
