/**
 * @fileOverview Sample for sending a QueryDB command
 * @name index.js
 * @author Cor Kalis <c.kalis@intoaccess.com>
 * @license UNLICENSED
 */
"use strict";

const http = require('http');

const PROTO = 'http:';
const PORT = 8088;
const PATH = '/QueryDB';
const HOST = '192.168.1.52';
const USER = 'RestUser';
const PWD = 'RestPassword';


/**
 * Send a ControlDoorEx command
 * @param {object} obj ControlDoorEx command data object
 * @param {function} callback Called when done
 */
function queryDb(obj, callback) {

  const strObj = JSON.stringify(obj);
  const bufObj = Buffer.from(strObj, 'utf-8');

  const req = http.request(
    {
      protocol: PROTO,
      hostname: HOST,
      port: PORT,
      path: PATH,
      method: 'POST',
      headers: {
        'Content-Type': 'application/json charset=utf-8',
        'Content-Length': Buffer.byteLength(bufObj)
      },
      auth: USER + ":" + PWD
    },
    (res) => {
      let reply = '';

      res.on('data', (chunk) => {
        reply += chunk;
      });

      res.on('end', () => {
        callback(null, reply);
      });
    }
  );

  req.on('error', (err) => {
    callback(err);
  });

  // Write data to request body
  req.write(bufObj);
  req.end();
}

// ======  Main ======

const query = 'select * from AccessLevels';

// Send the query
queryDb(query, (err, reply) => {
  if (err) {
    console.log('Oops:', err);
  } else {
    try {
      const replyObj = JSON.parse(reply);
      console.log(JSON.stringify(replyObj, null, 2));
    } catch(err) {
      console.log('Problem parsing the reply:', err);
    }
  }
});
