"""
Python3 sample script to call UpdateUserRecord
"""
import requests
import sys

# Post urls
URL1 = 'http://192.168.1.52:8088/ViewUserRecords'
URL2 = 'http://192.168.1.52:8088/UpdateUserRecord'

# Creds
USER_NAME = "RestUser"
PASSWORD = "RestPassword"


def translate(db_rec):
    """ Translate DB record to a UpdateUserRecord parameter object
    """
    result = {}
    result['userId'] = db_rec['UserID']
    result['accessLevelId'] = db_rec['AccessLevelID']
    result['departmentId'] = db_rec['DepartmentID']
    result['firstName'] = db_rec['FirstName']
    result['middleName'] = db_rec['MiddleName']
    result['surname'] = db_rec['Surname']
    result['antiPassbackInd'] = db_rec['AntiPassbackUser']
    result['activeInd'] = db_rec['Active']
    result['pinCode'] = db_rec['PIN']
    result['alarmUserInd'] = db_rec['AlarmUser']
    result['telephoneNo'] = db_rec['Telephone']
    result['telephoneExtension'] = db_rec['Extension']
    result['faxNo'] = db_rec['Fax']
    result['activationDate'] = db_rec['ActivateDate']
    result['expiryDate'] = db_rec['ExpiryDate']
    result['customFields'] = [
        None,
        db_rec['Field1_100'],
        db_rec['Field2_100'],
        db_rec['Field3_50'],
        db_rec['Field4_50'],
        db_rec['Field5_50'],
        db_rec['Field6_50'],
        db_rec['Field7_50'],
        db_rec['Field8_50'],
        db_rec['Field9_50'],
        db_rec['Field10_50'],
        db_rec['Field11_50'],
        db_rec['Field12_50'],
        db_rec['Field13_Memo'],
        db_rec['Field14_50']
    ]
    return result


# ====== Main ======
# User to update
user_id = 18

# --- Fetch existing record ---
req = requests.post(URL1,
                    auth=(USER_NAME, PASSWORD),
                    json='UserId=%d' % (user_id))
if (req.status_code != 200):
    print('Bad response code: %d' % (req.status_code))
    sys.exit(1)

resp = req.json()
if not resp:
    print('Call to ViewUserRecords failed for user_id %d' % (user_id))
    sys.exit(1)

# First record must be it: translate it for use with UpdateUserRecord
rec = translate(resp[0])


# --- Set pin code of user ---
rec['pinCode'] = '9876'   # Set to empty string in order to clear existing pin
req = requests.post(URL2,
                    auth=(USER_NAME, PASSWORD),
                    json=rec)
if (req.status_code == 200):
    resp = req.json()
    print('Result of setting pin code: %s' % resp)
else:
    print('Bad response code: %d' % (req.status_code))
